{ pkgs, lib, ... }:

let
  secrets = toString ./secrets;
in

{
  imports = [
    <nixpkgs/nixos/modules/virtualisation/qemu-vm.nix>
    ./configuration.nix
  ];

  virtualisation.memorySize = "4000"; # MB
  virtualisation.graphics = false;

  virtualisation.qemu.options =
    [ # Ensure secrets are accessible by the
      # activation scripts at runtime.
      "-virtfs local,path=${secrets},security_model=none,mount_tag=secrets"
    ];

  virtualisation.fileSystems."${secrets}" =
    { device = "secrets";
      fsType = "9p";
      options = [ "trans=virtio" "version=9p2000.L" ];
      neededForBoot = true;
    };

  # Automatically resize the console
  environment.systemPackages = [ pkgs.xterm ];
  environment.shellInit = "resize > /dev/null";

}
